/**
 * Cat5171.h
 *
 * @created: May 15, 2020
 * @author: Aric Beaver
 * @brief Driver class for the CAT5171 digital potentiometer.
 */

#ifndef CAT5171_H
#define CAT5171_H

/* ============== USEFUL MACROS ============== */

#define CAT5171_DATA_SIZE 1

#define CAT5171_SD(x)       ((x & 0b00000001) << 5)
#define CAT5171_RS(x)       ((x & 0b00000001) << 6)

/* ============== CLASS DEFINITION ============== */

class Cat5171 {
public:

    enum Resistance {R50K = 50000, R100K = 100000};
    bool shutdown = false;

	Cat5171(I2C *i2c, uint8_t i2c_address, Resistance resistance);
	~Cat5171();

	bool readI2C(char *data);
    bool writeI2C(char ib, char *data);
    bool write(uint resistance);
    bool read(uint* resistance);
    bool rs();
    bool sd(bool value);

protected:
    /**
     * @member I2C object pointer
     */
    I2C *m_i2c;

	/**
	 * @member I2C address of this device
	 */
	int m_i2c_address;    

    /**
	 * @member Resistance of device attached and the valid ranges
	 */
    Resistance m_resistance;
};
#endif /* Cat5171_H */
